@@ -11,11 +11,13 @@ class LZ4FrameCompressor(object):
     Args:
         block_size (int): Sepcifies the maximum blocksize to use.
             Options:
-            - lz4.frame.BLOCKSIZE_DEFAULT or 0: the lz4 library default
-            - lz4.frame.BLOCKSIZE_MAX64KB or 4: 64 kB
-            - lz4.frame.BLOCKSIZE_MAX256KB or 5: 256 kB
-            - lz4.frame.BLOCKSIZE_MAX1MB or 6: 1 MB
-            - lz4.frame.BLOCKSIZE_MAX4MB or 7: 4 MB
+
+                - lz4.frame.BLOCKSIZE_DEFAULT or 0: the lz4 library default
+                - lz4.frame.BLOCKSIZE_MAX64KB or 4: 64 kB
+                - lz4.frame.BLOCKSIZE_MAX256KB or 5: 256 kB
+                - lz4.frame.BLOCKSIZE_MAX1MB or 6: 1 MB
+                - lz4.frame.BLOCKSIZE_MAX4MB or 7: 4 MB
+
             If unspecified, will default to lz4.frame.BLOCKSIZE_DEFAULT which
             is equal to lz4.frame.BLOCKSIZE_MAX64KB.
         block_linked (bool): Specifies whether to use block-linked
@@ -28,9 +30,11 @@ class LZ4FrameCompressor(object):
             Values above 16 will be treated as 16.
             Values between 4-9 are recommended. 0 is the default.
             The following module constants are provided as a convenience:
-            - lz4.frame.COMPRESSIONLEVEL_MIN: Minimum compression (0)
-            - lz4.frame.COMPRESSIONLEVEL_MINHC: Minimum high-compression (3)
-            - lz4.frame.COMPRESSIONLEVEL_MAX: Maximum compression (16)
+
+                - lz4.frame.COMPRESSIONLEVEL_MIN: Minimum compression (0)
+                - lz4.frame.COMPRESSIONLEVEL_MINHC: Minimum high-compression (3)
+                - lz4.frame.COMPRESSIONLEVEL_MAX: Maximum compression (16)
+
         content_checksum (bool): Specifies whether to enable checksumming of
             the payload content. If `True` a checksum of the uncompressed data
             is stored at the end of the compressed frame which is checked during
@@ -46,7 +50,7 @@ class LZ4FrameCompressor(object):
             to be raised.
         auto_flush (bool): When `False`, the LZ4 library may buffer data until a
             block is full. When `True` no buffering occurs, and partially full
-            blocks may be returned. The default is `True`.
+            blocks may be returned. The default is `False`.
         return_bytearray (bool): When `False` a bytes object is returned from the
             calls to methods of this class. When `True` a bytearray object will be
             returned. The default is `False`.
@@ -58,7 +62,7 @@ class LZ4FrameCompressor(object):
                  compression_level=COMPRESSIONLEVEL_MIN,
                  content_checksum=False,
                  block_checksum=False,
-                 auto_flush=True,
+                 auto_flush=False,
                  return_bytearray=False):
         self.block_size = block_size
         self.block_linked = block_linked
@@ -83,7 +87,7 @@ class LZ4FrameCompressor(object):
         # no need to del it here
         pass
 
-    def compress_begin(self, source_size=0):
+    def begin(self, source_size=0):
         """Begin a compression frame. The returned data contains frame header
         information. The data returned from subsequent calls to ``compress()``
         should be concatenated with this header.
@@ -213,10 +217,13 @@ class LZ4FrameDecompressor(object):
                 to contain the full LZ4 frame. Default is ``False``.
 
         Returns:
-            bytes or bytearray: decompressed data
-            int: Number of bytes consumed from input data. This is only returned if
-                ``return_bytes_read`` is ``True`` when ``LZ4FrameDecompressor`` is
-                instantiated.
+             bytes/bytearray or tuple: Uncompressed data
+
+             If the ``return_bytes_read`` argument is ``True`` this function
+             returns a tuple consisting of:
+
+                 - bytes or bytearray: Uncompressed data
+                 - int: Number of bytes consumed from ``data``
 
         """
 
